@@ -50,7 +50,6 @@ impl VisitMut for Prefixer {
                     value: $name.into(),
                     raw: $name.into(),
                 });
-
                 self.added.push(Declaration {
                     span: n.span,
                     name,
@@ -67,7 +66,6 @@ impl VisitMut for Prefixer {
                     value: $name.into(),
                     raw: $name.into(),
                 };
-
                 self.added.push(Declaration {
                     span: n.span,
                     name: n.name.clone(),
@@ -189,7 +187,7 @@ impl VisitMut for Prefixer {
                                 span: n.span,
                                 name: n.name.clone(),
                                 value: vec![val],
-                                important: n.important,
+                                important: n.important.clone(),
                             });
                         }
                     }
@@ -213,7 +211,7 @@ impl VisitMut for Prefixer {
                                 span: n.span,
                                 name: n.name.clone(),
                                 value: vec![val],
-                                important: n.important,
+                                important: n.important.clone(),
                             });
                         }
                     }
@@ -469,7 +467,9 @@ impl VisitMut for Prefixer {
 
             "transition" => {
                 let mut value = n.value.clone();
+
                 replace_ident(&mut value, "transform", "-webkit-transform");
+
                 let name = DeclarationName::Ident(Ident {
                     span: DUMMY_SP,
                     value: "-webkit-transition".into(),
@@ -479,7 +479,7 @@ impl VisitMut for Prefixer {
                     span: n.span,
                     name,
                     value,
-                    important: n.important,
+                    important: n.important.clone(),
                 });
             }
 
